Documentation
¶
Overview ¶
Package ipfyi provides a Go client for the IPFYI API (ipfyi.com).
IPFYI — zero dependencies, no authentication required.
Usage:
client := ipfyi.NewClient()
result, err := client.Search("query")
Index ¶
- Constants
- type Client
- func (c *Client) Asn(slug string) (map[string]interface{}, error)
- func (c *Client) Asns() (map[string]interface{}, error)
- func (c *Client) Cities() (map[string]interface{}, error)
- func (c *Client) City(slug string) (map[string]interface{}, error)
- func (c *Client) Faq(slug string) (map[string]interface{}, error)
- func (c *Client) Faqs() (map[string]interface{}, error)
- func (c *Client) GlossaryCategories() (map[string]interface{}, error)
- func (c *Client) GlossaryCategory(slug string) (map[string]interface{}, error)
- func (c *Client) GlossaryTerm(slug string) (map[string]interface{}, error)
- func (c *Client) GlossaryTerms() (map[string]interface{}, error)
- func (c *Client) IpRange(slug string) (map[string]interface{}, error)
- func (c *Client) IpRanges() (map[string]interface{}, error)
- func (c *Client) Isp(slug string) (map[string]interface{}, error)
- func (c *Client) Isps() (map[string]interface{}, error)
- func (c *Client) Search(query string) (map[string]interface{}, error)
- func (c *Client) Threat(slug string) (map[string]interface{}, error)
- func (c *Client) Threats() (map[string]interface{}, error)
Constants ¶
const DefaultBaseURL = "https://ipfyi.com"
DefaultBaseURL is the default API base URL.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client is a IPFYI API client.
func (*Client) GlossaryCategories ¶
GlossaryCategories returns a list of glossary categories.
func (*Client) GlossaryCategory ¶
GlossaryCategory returns details for a glossary category by slug.
func (*Client) GlossaryTerm ¶
GlossaryTerm returns details for a glossary term by slug.
func (*Client) GlossaryTerms ¶
GlossaryTerms returns a list of glossary terms.
Click to show internal directories.
Click to hide internal directories.